timeintervaltools.group_tangent_or_overlapping_intervals_and_yield_groups
=========================================================================

.. autofunction:: abjad.tools.timeintervaltools.group_tangent_or_overlapping_intervals_and_yield_groups.group_tangent_or_overlapping_intervals_and_yield_groups
